﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace EFSample
{
    class Program
    {
        static void Main(string[] args)
        {
            IList<BlogUser> blogUsers = TestEF.GetAllBlogUsers();

            ///遍历所有查询结果
            foreach (var blogUser in blogUsers)
            {
                Console.WriteLine(blogUser);

                ///获取外键对象的内容
                foreach (var post in blogUser.Posts)
                {
                    Console.WriteLine("\t 随笔标题：{0}", post.PostTitle);

                    foreach (var comment in post.Comments)
                    {
                        Console.WriteLine("\t\t{0}", comment.CommentContent);
                    }
                }
            }


        
            
        }
    }

    public static class TestEF
    {
        public static IList<BlogUser> GetAllBlogUsers()
        {
            
            ///BlogDBEntities是继承于ObjectContext类，自动生成
            ///可以打开Blog.Desgner.cs文件找到
            ///原型： public partial class BlogDBEntities : ObjectContext
            ///可以理解为 他代表了当前数据库环境对象
            ///同时，在Blog.Desgner.cs里还可以找到两个实体BlogUser及Post
            using (BlogDBEntities blogDB = new BlogDBEntities())
            {

                ///采用Linq语法读取数据
                ///通过Include方法将子对象Post预先加载
                IList<BlogUser> blogUsers = blogDB.BlogUsers.Include("Posts").ToList<BlogUser>();

                foreach (var item in blogUsers)
                {
                    foreach (var post in item.Posts)
                    {
                        //对于Comments对象，也进行了预加载
                        if (!post.Comments.IsLoaded)
                        {
                            post.Comments.Load();
                        }
                    }
                }
                return blogUsers;
            }
            
        }   
    }

    public partial class BlogUser
    {
        public override string ToString()
        {
            return string.Format("编号：{0} 姓名:{1}", this.BlogID, this.BlogName);
        }
    }
    public partial class Category
    {
        public int CategoryID { get; set; }

        public string CategoryName { get; set; }
        
    }
}
